'use strict';

var css = require('@master/css');
var cssDataProvider = require('./css-data-provider.cjs');
var vscodeLanguageserverProtocol = require('vscode-languageserver-protocol');
var sortCompletionItems = require('./sort-completion-items.cjs');
var getCssDataDocumentation = require('./get-css-data-documentation.cjs');

const kind = vscodeLanguageserverProtocol.CompletionItemKind.Function;
function getPseudoClassCompletionItems(css$1 = new css.MasterCSS(), syntax) {
    const pseudoClassDataList = cssDataProvider.providePseudoClasses().filter((data)=>{
        // exclude @page pseudo-classes
        if ([
            ':first',
            ':left',
            ':right',
            ':blank'
        ].includes(data.name)) return false;
        return true;
    });
    const completionItems = pseudoClassDataList.map((data)=>{
        // fix https://github.com/microsoft/vscode-custom-data/issues/78
        const name = /:(?:dir|has|is|nth-col|where)/.test(data.name) ? data.name + '()' : data.name;
        let sortText = name.startsWith(':-') ? 'yyyy' + name.slice(2) : 'yy' + name.replace(/^:/, '');
        if (sortText.endsWith('()')) sortText = 'y' + sortText;
        return {
            label: name,
            sortText,
            documentation: getCssDataDocumentation.getCSSDataDocumentation(data, {
                generatedCSS: css.generateCSS([
                    syntax + name.slice(1)
                ], css$1),
                docs: '/guide/selectors'
            }),
            kind,
            data
        };
    });
    const selectors = {
        ...css$1.config.selectors,
        ':of': ':of'
    };
    for(const name in selectors){
        if (name.startsWith('::')) continue;
        const value = selectors[name];
        const data = pseudoClassDataList.find((data)=>value.startsWith(data.name));
        let sortText = name.startsWith(':-') ? 'yyyy' + name.slice(2) : 'yy' + name.replace(/^:/, '');
        if (sortText.endsWith('()')) sortText = 'y' + sortText;
        const completionItem = {
            label: name,
            documentation: getCssDataDocumentation.getCSSDataDocumentation(data, {
                generatedCSS: css.generateCSS([
                    syntax + name.slice(1)
                ], css$1),
                docs: '/guide/selectors'
            }),
            sortText,
            kind,
            detail: String(value),
            data
        };
        completionItems.push(completionItem);
    }
    return sortCompletionItems(completionItems);
}

module.exports = getPseudoClassCompletionItems;
